<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL: https://svn.osuosl.org/public/maintain-project/trunk/class/htdocs/DB_DataObjectDataList.php $
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Authors: Daniel Robert <robert@osuosl.org>                             |
// +------------------------------------------------------------------------+
   
// $Id: DB_DataObjectDataList.php 4553 2006-06-29 20:22:57Z bartel $

/**
  * DB_DataObjectDataList.php - contains the {@link DB_DataObjectDataList} class
  *
  * @author $Author: bartel $
  * @filesource
  * @package    htdocs
  * @subpackage datalists
  */

require_once($phphtmllib.'/widgets/data_list/DefaultGUIDataList.inc');

/**
  * This class overloads methods from DefaultGUIDataList
  * to tailor it for DB_DataObjects and Maintain's needs
  *
  * @link   http://phphtmllib.newsblob.com/javadoc.php phpHtmlLib API Documentation
  * @link   http://phphtmllib.newsblob.com/doc/phpHtmlLib/DefaultGUIDatalist.html
            DefaultGUIDataList API Documentation
  * @package    classes
  * @subpackage htdocs
  */
class DB_DataObjectDataList extends DefaultGUIDataList
{

// {{{ user_setup_init()
    
    /**
      * Helper method for user_setup() that initializes
      * certain variables such as number of rows to display,
      * the 'action=show' REQUEST variable, etc.
      *
      * child classes' user_setup() function had best call this method
      *
      * @access protected
      */
    function user_setup_init()
    {
        // set up the table pagination stuff at the bottom
        $this->set_actionbar(true);

        // keep the 'action=show' REQUEST variable
        $this->set_save_vars(array('action'=>'show'));

        // set the number of rows to display per page
        $this->set_default_num_rows($this->_get_maintain_default_rows());

        // specify the form method/action
        $this->set_form_action($_SERVER['SCRIPT_NAME']);
        $this->set_form_method("post");

        // hide the simple search modifier
        // _build_simple_search_form() turns on 'contains' search
        //$this->set_simple_search_modifier(SEARCH_CONTAINS);
        $this->_simple_search_modifier = false;
    }

// }}}
// {{{ actionbar_cell()

    /**
      * Table pagination...I hate that this is at the bottom,
      * but it's the only place I could figure out where to put it
      *
      * @internal
      */
    function actionbar_cell()
    {
        $current    = $this->get_current_page();
        $pages      = $this->get_num_pages();
        return html_span('', _("You are on page") . " $current "
                . _("of") . " $pages");
    }

// }}}
// {{{ build_column_item()

    /**
      * How to display the data in each column for each row
      *
      * @param  array   array of row data
      * @param  string  the name of the column we're on (index in the array)
      * @return object  phpHtmlLib
      {@link http://phphtmllib.newsblob.com/doc/phpHtmlLib/Container.html Container}
      object
      */
    function build_column_item($row_data, $col_name) 
    {
        return parent::build_column_item($row_data, $col_name); 
    }

// }}}
// {{{ user_setup()

    /**
      * Configure the columns for this datalist
      * by calling child_classes' "_user_setup()" method
      *
      * This ensures that user_setup_init() is called for every
      * datalist, without worrying about if user_setup was overloaded properly
      *
      * Calls {@link _user_setup}
      *
      * @link http://phphtmllib.newsblob.com/javadoc.php phpHtmlLib API Documentation
      * @link http://phphtmllib.newsblob.com/doc/phpHtmlLib/DataList.html#methoduser_setup
              user_setup API documentation
      */
    function user_setup() 
    {
        $this->user_setup_init();
        $this->_user_setup();
    }

// }}}
// {{{ set_global_prefix()

    /**
      * Overloads DefaultGUIDataList's function as it defines
      * the variable names
      *
      * @param  string  the prefix for all vars
      */
    function set_global_prefix($prefix) 
    {
        DataList::set_global_prefix($prefix);
    }

// }}}
// {{{ set_radiovar()

    /**
      * Specify the variable name for a column of radio buttons
      *
      * @param  string  name of variable
      */
    function set_radiovar($name = 'radio')
    {
        $this->_vars['radioVar'] = $name;
    }

// }}}
// {{{ set_checkboxvar()

    /**
      * Specify the variable name for a column of checkboxes
      *
      * @param  string  name of variable
      */
    function set_checkboxvar($name = 'checkbox')
    {
        $this->_vars['checkboxVar'] = $name;
    }

// }}}

// {{{ _get_maintain_default_rows()

    /**
      * Determine the number of rows to display per page of a table
      * based on the user's settings, failing back on the config's settings
      *
      * @access private
      * @global object  the current User object
      * @return int     the number of rows to display per page
      */
    function _get_maintain_default_rows()
    {
        global $user;

        if ($user->list_view) {
            return $user->list_view;
        } else {
            return $conf['general']['max_list'];
        }
    }

// }}}
// {{{ _build_simple_search_form()
/**
  * Build the simple search form (on top of the datalist).
  * Adds hidden search modifier so that search defaults to 'contains'
  * rather than exact search.
  */
    function _build_simple_search_form()
    {
        $searchmod = new FEHidden('simple_search_modifier', 'CONTAINS');
        $searchform = parent::_build_simple_search_form();

        if ($searchform != null && $searchmod != null)
            $searchform->add($searchmod->get_element());
        return $searchform;
    }
// }}}


/* Abstract Methods */
// {{{ get_data_source()

    /**
      * Setup the data source for this datalist
      * @abstract
      */
    function get_data_source() { parent::get_data_source(); }

// }}}
// {{{ _user_setup()

    /**
      * Implements user_setup() for this datalist
      *
      * @abstract
      * @link http://phphtmllib.newsblob.com/javadoc.php phpHtmlLib API Documentation
      * @link http://phphtmllib.newsblob.com/doc/phpHtmlLib/DataList.html#methoduser_setup
              user_setup API documentation
      */
    function _user_setup() {}

// }}}

}

?>
