<?php 

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL:$
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Michael Clay <claym@osuosl.org>                             |
// |            Frederic Wenzel <fred@osuosl.org>                           |
// +------------------------------------------------------------------------+
// $Id: DHCPOCreateForm.php 4606 2006-07-12 22:41:37Z morgabra $

/**
 *  DHCPOCreateForm.php - This form contains the {@link DHCPOCreateForm} class
 *
 *  @author     $Author$
 *  @package    htdocs
 *  @subpackage forms
 *  @filesource
 */

require_once(FORMDIR."/MaintainForm.php");

/**
 *  DHCPOCreateForm - The creation form for DHCP Options
 *
 *  @package    htdocs
 *  @subpackage forms
 */
class DHCPOCreateForm extends MaintainForm
{

//{{{   Vars
    var $map = array('Name'=>'name',
                    'Option_Type'=>'type',
                    'Access_Level'=>'access',
                    'Custom_Option?'=>'custom',
                    'Custom_Option_Space'=>'space',
                    'Custom_Option_Value'=>'value',
                    'Status'=>'enabled');
//}}}

//{{{   form_init_elements()

    /**
     * Init the elements that are going to be part of the form
     */
    function form_init_elements()
    {   
        $name = new FEText(_("Name"), true);
        $type = new FEListBox(_("Option Type"), true);
        $access = new FEListbox(_("Access Level"), true);
        $enable = new FEListBox(_("Status"), true);
        $custom = new FECheckbox(_("Custom Option?"));
        $custspace = new FEText(_("Custom Option Space"));
        $custvalue = new FEText(_("Custom Option Value"));

        $typeary = array('Default'=>'default',
                        'Option'=>'option',
                        'Quoted'=>'quoted',
                        'Quoted-Option'=>'quoted-option');

        $type->set_list_data($typeary);

        $accessary = array('Zone Admin'=>50,
                            'Admin'=>100);
        
        $access->set_list_data($accessary);

        $enableary = array('Enable'=>'true',
                            'Disable'=>'false');

        $enable->set_list_data($enableary);

        $this->add_elements($name, $type, $access, $enable, $custom, $custspace, $custvalue);
    }

//}}}
//{{{   form_backend_validation ()

    /**
     *  This method is responisble for validating the form data before it goes
     *  into the backend.
     *
     *  @return Boolean True if data is valid
     */
    function form_backend_validation()
    {
        $dhcpo = new DHCPOption($_REQUEST['id']);
        $res = true;
        
        $ary = $this->get_all_element_values();

        $daoary = $this->remap($ary, DBDO);

        if(!isset($daoary['custom']))
            $daoary['custom'] = 0;

        $dhcpo->setFrom($daoary);

        $valid = $dhcpo->validate();

        if($valid !== true) {
            $res = false;
            $errors = $this->remap($valid, FORM);
            foreach($errors as $label=>$error)  {
                if ($error !== true)
                    $this->add_error($label, $error);
            }
        }

        return $res;
    }

//}}}
//{{{   form_action()

    /**
     *  This method is performed after validation, and is responisble for actually
     *  adding the option into the database.
     *
     *  @return Boolean True if successfully added to the database
     */
    function form_action()
    {
        global $user;

        $res = true;
        $dbdo = new DHCPOption();
        $dbdo->query("BEGIN");
        $vals = $this->get_all_element_values();
        
        if(!isset($vals['custom']))
            $vals['custom'] = 0;
            
        $objary = $this->remap($vals, DBDO);
        $dbdo->setFrom($objary);
        
        if(!$dbdo->insert()) {
            $dbdo->query("ROLLBACK");
            $res = false;
            $this->add_error(_("ERROR"), _("Could not add entry to the database"));
        } else {
            $dbdo->query("COMMIT");
            $dbdo->write_history(_("DHCP Option Created"), ACTION_CREATE,
                                $user->username, $_SESSION['zone']);
        }

        return $res;
    }

//}}}
//{{{   form_success()

    /**
     *  This method is ran if form_action() was successful, we use it to display
     *  a success message to the users upon completion of the create.
     *
     *  @return DIVTag  $div    Div that contains a success message
     */
    function form_success()
    {
        $div = html_div("msuccess");
        $indlink = html_a(web_root()."index.php", _("[Return to Home]"));
        $link = html_a(web_root()."dhcp.php", _("[Return to DHCP Option List]"));
        $div->add(container(_("DHCP Option Created Successfully"), html_br()));
        $div->add(container($indlink,$link));
        return $div;
    }

//}}}

}

?>
